@@ -83,7 +83,8 @@ sub init_server_root
   {
     if( $^O =~ m{win32}i )
     {
-      $s->{web}{page_cache_root} = "$ENV{TMP}\\PAGE_CACHE";
+      my $temp_root = $ENV{TMP} || $ENV{TEMP};
+      $s->{web}{page_cache_root} = "$temp_root\\PAGE_CACHE";
     }
     else
     {
@@ -93,13 +94,13 @@ sub init_server_root
    
   unless( -d $s->{web}{page_cache_root} )
   {
-    my @parts = split /\//, $s->{web}{page_cache_root};
-    my $root = "/";
+    my @parts = split /[\/\\]/, $s->{web}{page_cache_root};
+    my $root = $^O =~ m{win32}i ? '' : "/";
     while( my $next = shift(@parts) )
     {
       $root .= "$next/";
       mkdir($root) unless -d $root;
-      die "Cannot create path to '@{[ $s->page_cache_root ]}' - stopped at '$root': $!"
+      die "Cannot create path to '@{[ $s->web->page_cache_root ]}' - stopped at '$root': $!"
         unless -d $root;
       chmod(0777, $root);
     }# end while()
@@ -107,9 +108,9 @@ sub init_server_root
   
   (my $compiled_root = $s->{web}->{page_cache_root} . '/' . $s->{web}->{application_name}) =~ s/::/\//g;
   my $folder = "";
-  foreach my $part ( grep { $_ } split /\//, $compiled_root )
+  foreach my $part ( grep { $_ } split /[\/\\]/, $compiled_root )
   {
-    $folder .= "/$part";
+    $folder .= "$part/";
     unless( -d $folder )
     {
       mkdir($folder);
@@ -283,3 +284,4 @@ This software is Free software and is licensed under the same terms as perl itse
 
 =cut
 
+
